@@ -1,8 +1,26 @@
+/*  Copyright 1996-2006,2008,2009 Alain Knaff.
+ *  This file is part of mtools.
+ *
+ *  Mtools is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  Mtools is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with Mtools.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #include "sysincludes.h"
 #include "msdos.h"
 #include "stream.h"
 #include "mtools.h"
 #include "fsP.h"
+#include "file_name.h"
 
 #ifdef HAVE_LONG_LONG
 typedef long long fatBitMask;
@@ -607,7 +625,7 @@ static int check_fat(Fs_t *This)
  * Read the first sector of FAT table into memory.  Crude error detection on
  * wrong FAT encoding scheme.
  */
-static int check_media_type(Fs_t *This, struct bootsector *boot, 
+static int check_media_type(Fs_t *This, union bootsector *boot, 
 			    unsigned int tot_sectors)
 {
 	unsigned char *address;
@@ -635,13 +653,13 @@ static int check_media_type(Fs_t *This, struct bootsector *boot,
 		 * and 0xff.  Do not consider this as an error */
 		return 0;
 	
-	if((address[0] != boot->descr && boot->descr >= 0xf0 &&
+	if((address[0] != boot->boot.descr && boot->boot.descr >= 0xf0 &&
 	    ((address[0] != 0xf9 && address[0] != 0xf7) 
-	     || boot->descr != 0xf0)) || address[0] < 0xf0) {
+	     || boot->boot.descr != 0xf0)) || address[0] < 0xf0) {
 		fprintf(stderr,
 			"Bad media types %02x/%02x, probably non-MSDOS disk\n", 
 				address[0],
-				boot->descr);
+				boot->boot.descr);
 		return -1;
 	}
 
@@ -653,14 +671,14 @@ static int check_media_type(Fs_t *This, struct bootsector *boot,
 	return 0;
 }
 
-static int fat_32_read(Fs_t *This, struct bootsector *boot, 
+static int fat_32_read(Fs_t *This, union bootsector *boot, 
 		       unsigned int tot_sectors)
 {
 	int size;
 
 	This->fat_len = DWORD(ext.fat32.bigFat);
-	This->writeAllFats = !(boot->ext.fat32.extFlags[0] & 0x80);
-	This->primaryFat = boot->ext.fat32.extFlags[0] & 0xf;
+	This->writeAllFats = !(boot->boot.ext.fat32.extFlags[0] & 0x80);
+	This->primaryFat = boot->boot.ext.fat32.extFlags[0] & 0xf;
 	This->rootCluster = DWORD(ext.fat32.rootCluster);
 	This->clus_start = This->fat_start + This->num_fat * This->fat_len;
 
@@ -683,12 +701,12 @@ static int fat_32_read(Fs_t *This, struct bootsector *boot,
 	}
 	
 	set_fat32(This);
-	return(check_media_type(This,boot, tot_sectors) ||
+	return(check_media_type(This, boot, tot_sectors) ||
 	       check_fat(This));
 }
 
 
-static int old_fat_read(Fs_t *This, struct bootsector *boot, 
+static int old_fat_read(Fs_t *This, union bootsector *boot, 
 						int config_fat_bits,
 						size_t tot_sectors, int nodups)
 {
@@ -719,7 +737,7 @@ static int old_fat_read(Fs_t *This, struct bootsector *boot,
  * Read the first sector of the  FAT table into memory and initialize 
  * structures.
  */
-int fat_read(Fs_t *This, struct bootsector *boot, int fat_bits,
+int fat_read(Fs_t *This, union bootsector *boot, int fat_bits,
 	   size_t tot_sectors, int nodups)
 {
 	This->fat_error = 0;
@@ -976,5 +994,7 @@ int fs_free(Stream_t *Stream)
 				free(This->FatMap[i].data);		
 		free(This->FatMap);
 	}
+	if(This->cp)
+		cp_close(This->cp);
 	return 0;
 }
